@@ -5,6 +5,7 @@ from typing import List
 
 class Events(Enum):
     DATA = 'scraper:data'
+    METRICS = 'scraper:metrics'
     END = 'scraper:end'
     ERROR = 'scraper:error'
     INVALID_SESSION = 'scraper:invalid-session'
@@ -26,3 +27,12 @@ class EventData(NamedTuple):
     description_html: str = ''
     date: str = ''
     insights: List[str] = []
+
+
+class EventMetrics:
+    processed: int = 0  # Number of successfully processed jobs
+    failed: int = 0  # Number of jobs failed to process
+    missed: int = 0  # Number of missed jobs to load during scraping
+
+    def __str__(self):
+        return f'{{ processed: {self.processed}, failed: {self.failed}, missed: {self.missed} }}'
